# coding: utf-8

"""
    FlexPrice API

    FlexPrice API Service

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class TypesWindowSize(str, Enum):
    """
    TypesWindowSize
    """

    """
    allowed enum values
    """
    MINUTE = 'MINUTE'
    ENUM_15MIN = '15MIN'
    ENUM_30MIN = '30MIN'
    HOUR = 'HOUR'
    ENUM_3HOUR = '3HOUR'
    ENUM_6HOUR = '6HOUR'
    ENUM_12HOUR = '12HOUR'
    DAY = 'DAY'
    WEEK = 'WEEK'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TypesWindowSize from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    FlexPrice API

    FlexPrice API Service

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class TypesInvoiceType(str, Enum):
    """
    TypesInvoiceType
    """

    """
    allowed enum values
    """
    SUBSCRIPTION = 'SUBSCRIPTION'
    ONE_OFF = 'ONE_OFF'
    CREDIT = 'CREDIT'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TypesInvoiceType from a JSON string"""
        return cls(json.loads(json_str))


